==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/InMageRcmDisksDefaultInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.InMageRcmDisksDefaultInputArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.DiskAccountType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * InMageRcm disk input.
 * @property diskEncryptionSetId The DiskEncryptionSet ARM Id.
 * @property diskType The disk type.
 * @property logStorageAccountId The log storage account ARM Id.
 */
public data class InMageRcmDisksDefaultInputArgs(
    public val diskEncryptionSetId: Output<String>? = null,
    public val diskType: Output<Either<String, DiskAccountType>>,
    public val logStorageAccountId: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.InMageRcmDisksDefaultInputArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.InMageRcmDisksDefaultInputArgs =
        com.pulumi.azurenative.recoveryservices.inputs.InMageRcmDisksDefaultInputArgs.builder()
            .diskEncryptionSetId(diskEncryptionSetId?.applyValue({ args0 -> args0 }))
            .diskType(
                diskType.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .logStorageAccountId(logStorageAccountId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InMageRcmDisksDefaultInputArgs].
 */
@PulumiTagMarker
public class InMageRcmDisksDefaultInputArgsBuilder internal constructor() {
    private var diskEncryptionSetId: Output<String>? = null

    private var diskType: Output<Either<String, DiskAccountType>>? = null

    private var logStorageAccountId: Output<String>? = null

    /**
     * @param value The DiskEncryptionSet ARM Id.
     */
    @JvmName("giuujjdlfqteynnb")
    public suspend fun diskEncryptionSetId(`value`: Output<String>) {
        this.diskEncryptionSetId = value
    }

    /**
     * @param value The disk type.
     */
    @JvmName("bwoacmywlyooynpu")
    public suspend fun diskType(`value`: Output<Either<String, DiskAccountType>>) {
        this.diskType = value
    }

    /**
     * @param value The log storage account ARM Id.
     */
    @JvmName("khtyjihxjvbohynw")
    public suspend fun logStorageAccountId(`value`: Output<String>) {
        this.logStorageAccountId = value
    }

    /**
     * @param value The DiskEncryptionSet ARM Id.
     */
    @JvmName("aduskxvokqfahhva")
    public suspend fun diskEncryptionSetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskEncryptionSetId = mapped
    }

    /**
     * @param value The disk type.
     */
    @JvmName("uavnsjyijtybbicm")
    public suspend fun diskType(`value`: Either<String, DiskAccountType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The disk type.
     */
    @JvmName("siqbqdmpvsexmwls")
    public fun diskType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DiskAccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The disk type.
     */
    @JvmName("mkfuthtjjslabhdr")
    public fun diskType(`value`: DiskAccountType) {
        val toBeMapped = Either.ofRight<String, DiskAccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The log storage account ARM Id.
     */
    @JvmName("xhxcghqvobtjgdqb")
    public suspend fun logStorageAccountId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.logStorageAccountId = mapped
    }

    internal fun build(): InMageRcmDisksDefaultInputArgs = InMageRcmDisksDefaultInputArgs(
        diskEncryptionSetId = diskEncryptionSetId,
        diskType = diskType ?: throw PulumiNullFieldException("diskType"),
        logStorageAccountId = logStorageAccountId ?: throw PulumiNullFieldException("logStorageAccountId"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/InMageRcmDisksDefaultInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.InMageRcmDisksDefaultInputArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.DiskAccountType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * InMageRcm disk input.
 * @property diskEncryptionSetId The DiskEncryptionSet ARM Id.
 * @property diskType The disk type.
 * @property logStorageAccountId The log storage account ARM Id.
 */
public data class InMageRcmDisksDefaultInputArgs(
    public val diskEncryptionSetId: Output<String>? = null,
    public val diskType: Output<Either<String, DiskAccountType>>,
    public val logStorageAccountId: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.InMageRcmDisksDefaultInputArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.InMageRcmDisksDefaultInputArgs =
        com.pulumi.azurenative.recoveryservices.inputs.InMageRcmDisksDefaultInputArgs.builder()
            .diskEncryptionSetId(diskEncryptionSetId?.applyValue({ args0 -> args0 }))
            .diskType(
                diskType.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .logStorageAccountId(logStorageAccountId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InMageRcmDisksDefaultInputArgs].
 */
@PulumiTagMarker
public class InMageRcmDisksDefaultInputArgsBuilder internal constructor() {
    private var diskEncryptionSetId: Output<String>? = null

    private var diskType: Output<Either<String, DiskAccountType>>? = null

    private var logStorageAccountId: Output<String>? = null

    /**
     * @param value The DiskEncryptionSet ARM Id.
     */
    @JvmName("uxcwjgnelneffytw")
    public suspend fun diskEncryptionSetId(`value`: Output<String>) {
        this.diskEncryptionSetId = value
    }

    /**
     * @param value The disk type.
     */
    @JvmName("rltlekapnpwtognj")
    public suspend fun diskType(`value`: Output<Either<String, DiskAccountType>>) {
        this.diskType = value
    }

    /**
     * @param value The log storage account ARM Id.
     */
    @JvmName("vquveevwsdblsdwx")
    public suspend fun logStorageAccountId(`value`: Output<String>) {
        this.logStorageAccountId = value
    }

    /**
     * @param value The DiskEncryptionSet ARM Id.
     */
    @JvmName("pqrgeqlsmgqylkxd")
    public suspend fun diskEncryptionSetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskEncryptionSetId = mapped
    }

    /**
     * @param value The disk type.
     */
    @JvmName("oedrfiaadhvgchbx")
    public suspend fun diskType(`value`: Either<String, DiskAccountType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The disk type.
     */
    @JvmName("wpkxigfavtpbxikr")
    public fun diskType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DiskAccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The disk type.
     */
    @JvmName("rncsbdfmbvjhqjjr")
    public fun diskType(`value`: DiskAccountType) {
        val toBeMapped = Either.ofRight<String, DiskAccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The log storage account ARM Id.
     */
    @JvmName("kcrlchyahsmgcjhq")
    public suspend fun logStorageAccountId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.logStorageAccountId = mapped
    }

    internal fun build(): InMageRcmDisksDefaultInputArgs = InMageRcmDisksDefaultInputArgs(
        diskEncryptionSetId = diskEncryptionSetId,
        diskType = diskType ?: throw PulumiNullFieldException("diskType"),
        logStorageAccountId = logStorageAccountId ?: throw PulumiNullFieldException("logStorageAccountId"),
    )
}
